pub trait ConformanceHooks<A: Accelerator> {
// Required method
fn complete_event(
&self,
backend: &A,
event: &A::Event,
) -> Result<(), BackendError>;
// Provided methods
fn resource_counts(&self, _backend: &A) -> Option<ResourceCounts> { ... }
fn submission_path_diagnostics(
&self,
_backend: &A,
) -> Option<SubmissionPathDiagnostics> { ... }
}Expand description
Provider-specific control needed by tests without weakening the [Accelerator] contract.
Required Methods
Sourcefn complete_event(
&self,
backend: &A,
event: &A::Event,
) -> Result<(), BackendError>
fn complete_event( &self, backend: &A, event: &A::Event, ) -> Result<(), BackendError>
Advance one pending event to its successful terminal state.
Provided Methods
Sourcefn resource_counts(&self, _backend: &A) -> Option<ResourceCounts>
fn resource_counts(&self, _backend: &A) -> Option<ResourceCounts>
Return live or indeterminate provider resource totals when the implementation exposes them.
Sourcefn submission_path_diagnostics(
&self,
_backend: &A,
) -> Option<SubmissionPathDiagnostics>
fn submission_path_diagnostics( &self, _backend: &A, ) -> Option<SubmissionPathDiagnostics>
Return cumulative provider copy-path diagnostics when the implementation exposes them.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".